texlive[72881] trunk: doc,sync

commits+karl at tug.org commits+karl at tug.org
Sun Nov 17 22:53:51 CET 2024


Revision: 72881
          https://tug.org/svn/texlive?view=revision&revision=72881
Author:   karl
Date:     2024-11-17 22:53:51 +0100 (Sun, 17 Nov 2024)
Log Message:
-----------
doc,sync

Modified Paths:
--------------
    trunk/Build/source/README
    trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
    trunk/Master/tlpkg/bin/tl-update-auto

Modified: trunk/Build/source/README
===================================================================
--- trunk/Build/source/README	2024-11-17 21:31:26 UTC (rev 72880)
+++ trunk/Build/source/README	2024-11-17 21:53:51 UTC (rev 72881)
@@ -48,12 +48,9 @@
     LDFLAGS='-Wl,--no-insert-timestamp -Wl,--stack,0x800000'" \
   ./Build
   
-i386-freebsd amd64-freebsd:
-  Built on contextgarden, see below.
-  FreeBSD 11.4
-  upstream: https://www.freshports.org/devel/tex-web2c/
+i386-freebsd amd64-freebsd: see info at end.
 
-i386-linux: see travis below.
+i386-linux: see info at end.
 
 i386-netbsd, amd64-netbsd:
   NetBSD/amd64 9.3
@@ -60,13 +57,11 @@
   gcc version 7.5.0 (nb4 20200810)
     TL_MAKE=gmake CC=gcc CXX=g++ \
     CFLAGS=-D_NETBSD_SOURCE \
-    CXXFLAGS='-D_NETBSD_SOURCE -std=c++11' \
+    CXXFLAGS='-D_NETBSD_SOURCE -std=c++17' \
     LDFLAGS='-L/usr/X11R7/lib -Wl,-rpath,/usr/X11R7/lib' \
   ./Build --enable-xindy CLISP=/usr/local/bin/clisp
 
-i386-solaris, x86_64-solaris:
-  Built on contextgarden, see below.
-  Solaris 10, gcc 5.5.  See doc/README.solaris.
+i386-solaris, x86_64-solaris: see info at end.
 
 universal-darwin: See Master/source/mactexdoc.tar.xz.
 
@@ -81,13 +76,8 @@
   http://build.contextgarden.net/waterfall?tag=c/texlive
   (These links have info on all platforms built by Mojca.)
 
-i386-linux,
 x86_64-linux,
-x86_64-linuxmusl:
-  CentOS 7 Docker image with musl libc 1.1.5, plus gcc10:
-    yum -y install centos-release-scl-rh
-    yum -y install devtoolset-9-gcc-c++
-    yum install -y fontconfig-devel libX11-devel libXmu-devel libXaw-devel
-  Binaries are taken from the CI testing via github;
-  see the source/.github/* files for details on how to build,
-  and tlpkg/bin/tl-update-bindir for updating binaries (in general).
+x86_64-linuxmusl,
+and others noted above:
+  built at https://github.com/TeX-Live/texlive-source/releases.
+  see ./github/scripts/build-tl.sh.

Modified: trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl
===================================================================
--- trunk/Master/tlpkg/bin/tl-update-auto	2024-11-17 21:31:26 UTC (rev 72880)
+++ trunk/Master/tlpkg/bin/tl-update-auto	2024-11-17 21:53:51 UTC (rev 72881)
@@ -44,7 +44,7 @@
 
 
 # 
 autogenerate README.EN from readme.html.
-# (skip, better to generate when needed and avoid spurious changes.)
+# (skip, better to generate when needed to avoid spurious changes.)
 #
 #if $config_scripts_only; then :; else
 #$mydir/htmltext <readme-html.dir/readme.en.html >$temp
@@ -266,7 +266,8 @@
     
 #     && rsync rsync://rsync.dante.ctan.org/MirMon/mirmon.state $ctan_mirmon; then
   elif wget -nv https://ctan.org/tex-archive/CTAN.sites -O $ctan_mirrors \
-     && scp -pq ctan.org:/serv/ctan/scripts/mirmon-2.11/mirmon.state $ctan_mirmon; then
+     && scp -pq ctan.org:/serv/ctan/scripts/mirmon-2.11/mirmon.state \
+                $ctan_mirmon; then
     #echo "got new mirror data"; ls -ltr $TMPDIR
     $mydir/tl-update-ctan-mirrors -v $ctan_mirrors $ctan_mirmon \
       >$mirrors4tl.new
@@ -285,7 +286,7 @@
   else
     echo "$0: ctan mirror data not retrievable, skipping." >&2
   fi
-fi # !config_scripts_only || !odd_day_num
+fi # !config_scripts_only
 
 
 # 
 curl cert bundle. Every other day is more than often enough.



More information about the tex-live-commits mailing list.
--- trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl	2024-11-17 21:31:26 UTC (rev 72880)
+++ trunk/Build/source/texk/texlive/linked_scripts/texlive/tlmgr.pl	2024-11-17 21:53:51 UTC (rev 72881)
@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: tlmgr.pl 71331 2024-05-24 07:30:36Z preining $
+# $Id: tlmgr.pl 72848 2024-11-14 15:14:04Z karl $
 # Copyright 2008-2024 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
 # or any later version.
@@ -8,8 +8,8 @@
 
 use strict; use warnings;
 
-my $svnrev = '$Revision: 71331 $';
-my $datrev = '$Date: 2024-05-24 09:30:36 +0200 (Fri, 24 May 2024) $';
+my $svnrev = '$Revision: 72848 $';
+my $datrev = '$Date: 2024-11-14 16:14:04 +0100 (Thu, 14 Nov 2024) $';
 my $tlmgrrevision;
 my $tlmgrversion;
 my $prg;
@@ -2783,8 +2783,8 @@
 # tlmgr update --no-depends-at-all foo
 #   will absolutely only update foo not even taking .ARCH into account
 #
-# TLPDB->install_package INSTALLS ONLY ONE PACKAGE, no deps whatsoever
-# anymore. That has all to be done by hand.
+# TLPDB->install_package INSTALLS ONLY ONE PACKAGE, no deps whatsoever.
+# That has all to be done by hand.
 #
 sub machine_line {
   my ($flag1) = @_;
@@ -3836,8 +3836,8 @@
 #   . it does not care for whether a package seems to be installed or
 #     not (that is the --reinstall)
 #
-# TLPDB->install_package does ONLY INSTALL ONE PACKAGE, no deps whatsoever
-# anymore!  That has all to be done by the caller.
+# TLPDB->install_package does ONLY INSTALL ONE PACKAGE, no deps
+# whatsoever; that has all to be done by the caller.
 #
 sub action_install {
   init_local_db(1);
@@ -5244,7 +5244,7 @@
   # we create fmtutil.cnf, language.dat, language.def in TEXMFSYSVAR and
   # updmap.cfg in TEXMFDIST. The reason is that we are now using an
   # implementation of updmap that supports multiple updmap files.
   # Local adaptions should not be made there, but only in TEXMFLOCAL
   # or TEXMF(SYS)CONFIG updmap.cfg
   #
   chomp (my $TEXMFSYSVAR = `kpsewhich -var-value=TEXMFSYSVAR`);
@@ -6066,7 +6066,7 @@
       if (!check_file($a, $f)) {
         push @{$missingbins{$_}}, "bin/$a/${name}[engine=$engine]" if $mode;
 #      # unfortunately there are too many exceptions to this check:
-#      # cygwin symlinks pointing to .exe names, pdcsplain extras, mptopdf,
+#      # cygwin symlinks pointing to .exe names, pdfcsplain extras, mptopdf,
 #      # *latex-dev pointing to *latex instead of the binary. Instead of
 #      # writing all those error-prone tests, just give up.
 #      } elsif (-l $f) {
@@ -8666,7 +8666,7 @@
 
 The C<generate> action overwrites any manual changes made in the
 respective files: it recreates them from scratch based on the
-information of the installed packages, plus local adaptions.
+information of the installed packages, plus local adaptations.
 The TeX Live installer and C<tlmgr> routinely call C<generate> for
 all of these files.
 
@@ -9076,7 +9076,7 @@
 C<desktop_integration> is set, then some packages will install items in
 a sub-folder of the Start menu for C<tlmgr gui>, documentation, etc.  If
 C<fileassocs> is set, Windows file associations are made (see also the
-C<postaction> action).  Finally, if C<multiuser> is set, then adaptions
+C<postaction> action).  Finally, if C<multiuser> is set, then changes
 to the registry and the menus are done for all users on the system
 instead of only the current user.  All three options are on by default.
 
@@ -10591,7 +10591,7 @@
 distribution (L<https://tug.org/texlive>) and both are licensed under the
 GNU General Public License Version 2 or later.
 
-$Id: tlmgr.pl 71331 2024-05-24 07:30:36Z preining $
+$Id: tlmgr.pl 72848 2024-11-14 15:14:04Z karl $
 =cut
 
 # test HTML version: pod2html --cachedir=/tmp tlmgr.pl >/tmp/tlmgr.html
@@ -5244,7 +5244,7 @@
   # updmap.cfg in TEXMFDIST. The reason is that we are now using an
   # implementation of updmap that supports multiple updmap files.
-  # Local adaptions should not be made there, but only in TEXMFLOCAL
+  # Local adaptations should not be made there, but only in TEXMFLOCAL
   # or TEXMF(SYS)CONFIG updmap.cfg
   #

Modified: trunk/Master/tlpkg/bin/tl-update-auto
===================================================================